pub struct ServiceAdapter<T>(/* private fields */);Expand description
Adapter to use a tower::Service as a rama::Service,
cloning the servicer for each request it has to serve.
Note that:
- you should use
SharedServiceAdapterin case you do not want it to beCloned, but instead shared across serve calls (we’ll wrap your tower service with aMutex); - you are required to use the
LayerServiceAdapterfor tower layer services, which will automatically be the case if you useLayerAdapterto wrap atower::Layer.
Halting
This adapter assumes that a service will always become ready eventually,
as it will call poll_ready until ready prior to calling the tower::Service.
Please ensure that your tower::Service does not require a side-step to prevent such halting.
Implementations
Sourceimpl<T: Clone + Send + Sync + 'static> ServiceAdapter<T>
impl<T: Clone + Send + Sync + 'static> ServiceAdapter<T>
Sourcepub fn new(svc: T) -> Self
pub fn new(svc: T) -> Self
Adapt a Clone/call tower::Service into a rama::Service.
See ServiceAdapter for more information.
Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Consume itself to return the inner tower::Service back.