pub struct SharedServiceAdapter<T>(/* private fields */);Expand description
Adapter to use a tower::Service as a rama::Service,
sharing the service between each request it has to serve.
Note that:
- you should use
ServiceAdapterin case you do not want it to be shared, and prefer it to beCloned instead, which is anyway the more “normal” scenario; - you are required to use the
LayerServiceAdapterfor tower layer services, which will automatically be the case if you useLayerAdapterto wrap atower::Layer.
Halting
This adapter assumes that a service will always become ready eventually,
as it will call poll_ready until ready prior to calling the tower::Service.
Please ensure that your tower::Service does not require a side-step to prevent such halting.
Implementations
Sourcepub fn new(svc: T) -> Self
pub fn new(svc: T) -> Self
Adapt a shared tower::Service into a rama::Service.
See SharedServiceAdapter for more information.